@@ -16,23 +16,17 @@
 #include <syscall.h>
 #include <asm/unistd.h>
 
-#ifndef __NR_set_ipv4root
-	#define __NR_set_ipv4root	227
-#endif
 // Here is the trick. We keep a copy of the define, then undef it
 // and then later, we try to locate the value reading /proc/self/status
 // If this fails, we have the old preserved copy.
-static int def_NR_set_ipv4root = __NR_set_ipv4root;
+static int def_NR_set_ipv4root = 227;
 #undef __NR_set_ipv4root
 
 static int __NR_set_ipv4root;
 
 _syscall1(int, set_ipv4root, unsigned long, ip);
 
-#ifndef __NR_new_s_context
-	#define __NR_new_s_context	226
-#endif
-static int def_NR_new_s_context = __NR_new_s_context;
+static int def_NR_new_s_context = 226;
 #undef __NR_new_s_context
 static int __NR_new_s_context;
 
