@@ -12,6 +12,7 @@
 
 	Changelog:
 
+	2002-02-28 Jacques Gelinas: Use dynamic system call
 	2002-06-05 Martial Rioux : fix memory output error
 	2002-12-05 Martial Rioux : fix output glitch
 	2001-11-29 added uptime/ctx stat
@@ -35,11 +36,8 @@
 #define CTX_DIR_NAME "/var/run/vservers/"
 #define CTX_NAME_MAX_LEN 50
 
-#ifndef __NR_new_s_context
-	#define __NR_new_s_context	226
-#endif
+int call_new_s_context(int newctx, int remove_cap, int flags);
 
-_syscall3(int, new_s_context, int, newctx, int, remove_cap, int, flags);
 
 struct ctx_list
 {
@@ -420,7 +418,7 @@ int main(int argc, char **argv)
 	my_pid = getpid();
 
 	// try to switch in context 1
-	if (new_s_context(1, 0, 0) < 0)
+	if (call_new_s_context(1, 0, 0) < 0)
 	{
 		fprintf(stderr, "%s: unable to switch in context security #1\n", process_name);
 		return -1;
